@@ -599,12 +599,18 @@ def avail_modules_tools():
         del class_dict['Modules']
     return class_dict
 
+
 def modules_tool(mod_paths=None):
     """
     Return interface to modules tool (environment modules, lmod)
     """
-    modules_tool_class = avail_modules_tools().get(get_modules_tool())
-    return modules_tool_class(mod_paths=mod_paths)
+    # get_modules_tool might return none (e.g. if config was not initialized yet)
+    modules_tool = get_modules_tool()
+    if modules_tool is not None:
+        modules_tool_class = avail_modules_tools().get(modules_tool)
+        return modules_tool_class(mod_paths=mod_paths)
+    else:
+        return None
 
 
 # provide Modules class for backward compatibility (e.g., in easyblocks)
