@@ -38,7 +38,7 @@ import os
 import re
 import sys
 from vsc import fancylogger
-from vsc.utils.missing import get_subclasses
+from vsc.utils.missing import get_subclasses, nub
 
 import easybuild.tools.toolchain
 from easybuild.tools.toolchain.toolchain import Toolchain
@@ -98,7 +98,7 @@ def search_toolchain(name):
                         setattr(package, tc_const_name, tc_const_value)
 
     # obtain all subclasses of toolchain
-    found_tcs = get_subclasses(Toolchain)
+    found_tcs = nub(get_subclasses(Toolchain))
 
     # filter found toolchain subclasses based on whether they can be used a toolchains
     found_tcs = [tc for tc in found_tcs if tc._is_toolchain_for(None)]
