@@ -355,7 +355,7 @@ class ExtOptionParser(OptionParser):
         elif self.description:
             description = formatter.format_description(self.get_description())
 
-        return description
+        return str(description)
 
     def set_usage(self, usage):
         """Return usage and set try to set autogenerated description."""
@@ -469,7 +469,7 @@ class ExtOptionParser(OptionParser):
 
         epilogprefixtxt = "All long option names can be passed as environment variables. "
         epilogprefixtxt += "Variable name is %(prefix)s_<LONGNAME> "
-        epilogprefixtxt += "eg. --someopt is same as setting %(prefix)s_SOMEOPT in the environment."
+        epilogprefixtxt += "eg. --some-opt is same as setting %(prefix)s_SOME_OPT in the environment."
         self.epilog.append(epilogprefixtxt % {'prefix': self.envvar_prefix})
 
         for opt in self._get_all_options():
@@ -478,7 +478,7 @@ class ExtOptionParser(OptionParser):
             for lo in opt._long_opts:
                 if len(lo) == 0:
                     continue
-                env_opt_name = "%s_%s" % (self.envvar_prefix, lo.lstrip('-').upper())
+                env_opt_name = "%s_%s" % (self.envvar_prefix, lo.lstrip('-').replace('-', '_').upper())
                 val = os.environ.get(env_opt_name, None)
                 if not val is None:
                     if opt.action in opt.TYPED_ACTIONS:  # not all typed actions are mandatory, but let's assume so
@@ -487,7 +487,10 @@ class ExtOptionParser(OptionParser):
                         # interpretation of values: 0/no/false means: don't set it
                         if not ("%s" % val).lower() in ("0", "no", "false",):
                             env_long_opts.append("%s" % lo)
+                else:
+                    self.log.debug("Environment variable %s is not set" % env_opt_name)
 
+        self.log.debug("Environment variable options with prefix %s: %s" % (self.envvar_prefix, env_long_opts))
         return env_long_opts
 
     def get_option_by_long_name(self, name):
@@ -1164,11 +1167,12 @@ class GeneralOption(object):
         return args
 
 
-def simple_option(go_dict, descr=None, short_groupdescr=None, long_groupdescr=None):
+def simple_option(go_dict=None, descr=None, short_groupdescr=None, long_groupdescr=None, config_files=None):
     """A function that returns a single level GeneralOption option parser
-    go_dict : General Option option dict
-    short_descr : short description of main options
-    long_descr : longer description of main options
+        @param go_dict : General Option option dict
+        @param short_descr : short description of main options
+        @param long_descr : longer description of main options
+        @param config_files : list of configfiles to read options from
 
     a general options dict has as key the long option name, and is followed by a list/tuple
         mandatory are 4 elements : option help, type, action, default
@@ -1191,9 +1195,15 @@ def simple_option(go_dict, descr=None, short_groupdescr=None, long_groupdescr=No
         PARSER = SimpleOptionParser
 
         def main_options(self):
-            prefix = None
-            self.add_group_parser(go_dict, descr, prefix=prefix)
+            if go_dict is not None:
+                prefix = None
+                self.add_group_parser(go_dict, descr, prefix=prefix)
 
-    return SimpleOption(go_prefixloggername=True,
-                        go_mainbeforedefault=True,
-                        )
+    kwargs = {
+              'go_prefixloggername': True,
+              'go_mainbeforedefault': True,
+              }
+    if config_files is not None:
+        kwargs['go_configfiles'] = config_files
+
+    return SimpleOption(**kwargs)
